@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::Author::OALDERS;
-$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000008';
+$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000009';
 use Moose;
 use namespace::autoclean;
 
@@ -32,7 +32,6 @@ use Dist::Zilla::Plugin::MetaResources;
 use Dist::Zilla::Plugin::MetaYAML;
 use Dist::Zilla::Plugin::MinimumPerl;
 use Dist::Zilla::Plugin::PkgVersion;
-use Dist::Zilla::Plugin::Pod2Readme;
 use Dist::Zilla::Plugin::PodCoverageTests;
 use Dist::Zilla::Plugin::PodWeaver;
 use Dist::Zilla::Plugin::Prereqs;
@@ -119,15 +118,14 @@ sub configure {
         'MetaYAML',
         'MinimumPerl',
         'PkgVersion',
-        'Pod2Readme',
         'PodCoverageTests',
         'PodWeaver',
         'Prereqs',
         'PruneCruft',
         [
-            'ReadmeAnyFromPod' => 'ReadmeMdInRoot' => {
+            'ReadmeAnyFromPod' => 'ReadmeMdInBuild' => {
                 filename => $readme,
-                location => 'root',
+                location => 'build',
                 type     => 'markdown',
             }
         ],
@@ -181,7 +179,7 @@ Dist::Zilla::PluginBundle::Author::OALDERS - A plugin bundle for distributions b
 
 =head1 VERSION
 
-version 0.000008
+version 0.000009
 
 =head2 configure
 
